@@ -5,7 +5,7 @@ use crate::{
     Parse,
 };
 use swc_atoms::js_word;
-use swc_common::{Span, DUMMY_SP};
+use swc_common::Span;
 use swc_css_ast::*;
 
 #[derive(Debug, Default)]
@@ -338,22 +338,24 @@ where
 {
     fn parse(&mut self) -> PResult<KeyframesRule> {
         let span = self.input.cur_span()?;
-        let name = match bump!(self) {
-            Token::Ident { value, raw } => KeyframesName::Ident(Ident {
-                span: span!(self, span.lo),
-                value,
-                raw,
-            }),
-            Token::Str { value, raw } => KeyframesName::Str(Str {
-                span: span!(self, span.lo),
-                value,
-                raw,
-            }),
-            _ => KeyframesName::Ident(Ident {
-                span: DUMMY_SP,
-                value: js_word!(""),
-                raw: js_word!(""),
-            }),
+        let name = match cur!(self) {
+            tok!("ident") => {
+                let custom_ident: CustomIdent = self.parse()?;
+
+                match &*custom_ident.value.to_ascii_lowercase() {
+                    "none" => {
+                        return Err(Error::new(
+                            span,
+                            ErrorKind::InvalidCustomIdent(stringify!(value)),
+                        ));
+                    }
+                    _ => {}
+                }
+
+                KeyframesName::CustomIdent(custom_ident)
+            }
+            tok!("str") => KeyframesName::Str(self.parse()?),
+            _ => return Err(Error::new(span, ErrorKind::Expected("ident or string"))),
         };
         let mut blocks = vec![];
 
@@ -461,7 +463,7 @@ where
 {
     fn parse(&mut self) -> PResult<SupportsRule> {
         let span = self.input.cur_span()?;
-        let query = self.parse()?;
+        let condition = self.parse()?;
 
         expect!(self, "{");
 
@@ -473,12 +475,172 @@ where
 
         Ok(SupportsRule {
             span: span!(self, span.lo),
-            query,
+            condition,
             rules,
         })
     }
 }
 
+impl<I> Parse<SupportsCondition> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<SupportsCondition> {
+        self.input.skip_ws()?;
+
+        let start_pos = self.input.cur_span()?.lo;
+        let mut last_pos;
+        let mut conditions = vec![];
+
+        if is!(self, "not") {
+            let not = self.parse()?;
+
+            last_pos = self.input.last_pos()?;
+
+            conditions.push(SupportsConditionType::Not(not));
+        } else {
+            let supports_in_parens = self.parse()?;
+
+            last_pos = self.input.last_pos()?;
+
+            conditions.push(SupportsConditionType::SupportsInParens(supports_in_parens));
+
+            self.input.skip_ws()?;
+
+            if is!(self, "and") {
+                while is!(self, "and") {
+                    let and = self.parse()?;
+
+                    last_pos = self.input.last_pos()?;
+
+                    conditions.push(SupportsConditionType::And(and));
+
+                    self.input.skip_ws()?;
+                }
+            } else if is!(self, "or") {
+                while is!(self, "or") {
+                    let or = self.parse()?;
+
+                    last_pos = self.input.last_pos()?;
+
+                    conditions.push(SupportsConditionType::Or(or));
+
+                    self.input.skip_ws()?;
+                }
+            }
+        };
+
+        Ok(SupportsCondition {
+            span: Span::new(start_pos, last_pos, Default::default()),
+            conditions,
+        })
+    }
+}
+
+impl<I> Parse<SupportsNot> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<SupportsNot> {
+        let span = self.input.cur_span()?;
+
+        expect!(self, "not");
+
+        self.input.skip_ws()?;
+
+        let supports_in_parens = self.parse()?;
+
+        Ok(SupportsNot {
+            span: span!(self, span.lo),
+            condition: supports_in_parens,
+        })
+    }
+}
+
+impl<I> Parse<SupportsAnd> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<SupportsAnd> {
+        let span = self.input.cur_span()?;
+
+        expect!(self, "and");
+
+        self.input.skip_ws()?;
+
+        let supports_in_parens = self.parse()?;
+
+        Ok(SupportsAnd {
+            span: span!(self, span.lo),
+            condition: supports_in_parens,
+        })
+    }
+}
+
+impl<I> Parse<SupportsOr> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<SupportsOr> {
+        let span = self.input.cur_span()?;
+
+        expect!(self, "or");
+
+        self.input.skip_ws()?;
+
+        let supports_in_parens = self.parse()?;
+
+        Ok(SupportsOr {
+            span: span!(self, span.lo),
+            condition: supports_in_parens,
+        })
+    }
+}
+
+impl<I> Parse<SupportsInParens> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<SupportsInParens> {
+        let state = self.input.state();
+
+        expect!(self, "(");
+
+        self.input.skip_ws()?;
+
+        if !is!(self, "(") && !is!(self, "not") {
+            self.input.reset(&state);
+
+            return Ok(SupportsInParens::Feature(self.parse()?));
+        }
+
+        let condition = SupportsInParens::SupportsCondition(self.parse()?);
+
+        expect!(self, ")");
+
+        Ok(condition)
+    }
+}
+
+impl<I> Parse<SupportsFeature> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<SupportsFeature> {
+        expect!(self, "(");
+
+        self.input.skip_ws()?;
+
+        let declaration = self.parse()?;
+
+        self.input.skip_ws()?;
+
+        expect!(self, ")");
+
+        Ok(SupportsFeature::Declaration(declaration))
+    }
+}
+
 impl<I> Parse<DocumentRule> for Parser<I>
 where
     I: ParserInput,
@@ -601,69 +763,6 @@ where
     }
 }
 
-impl<I> Parse<SupportQuery> for Parser<I>
-where
-    I: ParserInput,
-{
-    fn parse(&mut self) -> PResult<SupportQuery> {
-        self.input.skip_ws()?;
-
-        let span = self.input.cur_span()?;
-
-        if eat!(self, "not") {
-            let query = self.parse()?;
-            return Ok(SupportQuery::Not(NotSupportQuery {
-                span: span!(self, span.lo),
-                query,
-            }));
-        }
-
-        if eat!(self, "(") {
-            self.input.skip_ws()?;
-
-            let query = if is!(self, "(") {
-                let query = self.parse()?;
-
-                SupportQuery::Paren(ParenSupportQuery {
-                    span: span!(self, span.lo),
-                    query,
-                })
-            } else {
-                let declaration = self.parse()?;
-
-                SupportQuery::Declaration(declaration)
-            };
-
-            expect!(self, ")");
-            self.input.skip_ws()?;
-
-            if eat!(self, "and") {
-                let right = self.parse()?;
-
-                return Ok(SupportQuery::And(AndSupportQuery {
-                    span: span!(self, span.lo),
-                    left: Box::new(query),
-                    right,
-                }));
-            }
-
-            if eat!(self, "or") {
-                let right = self.parse()?;
-
-                return Ok(SupportQuery::Or(OrSupportQuery {
-                    span: span!(self, span.lo),
-                    left: Box::new(query),
-                    right,
-                }));
-            }
-
-            return Ok(query);
-        }
-
-        Err(Error::new(span, ErrorKind::InvalidSupportQuery))
-    }
-}
-
 impl<I> Parse<MediaRule> for Parser<I>
 where
     I: ParserInput,
@@ -985,7 +1084,7 @@ where
 
         expect!(self, ")");
 
-        return Ok(condition);
+        Ok(condition)
     }
 }
 
